==> haskell-language-c99-simple-0.2.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-c99-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 language-c99-simple
version:              0.2.3
visibility:           public
id:                   language-c99-simple-0.2.3-FO88MOT59BBAkxQlB4FWu0
key:                  language-c99-simple-0.2.3-FO88MOT59BBAkxQlB4FWu0
license:              MIT
maintainer:           Frank Dedden <dev@dedden.net>
author:               Frank Dedden
synopsis:             C-like AST to simplify writing C99 programs.
description:
    This package is a wrapper on top of '\''language-c99'\''. It provides a simpler
    interface more suited for writing C99 programs. It achieves this by
    implementing its own C-like AST, supporting the most used C features. In
    turn, this AST is translated into actual C99 one, showing that it is an
    actual subset.

category:             Language
abi:                  fafda335794d39854c2f94a9c7aa07d8
exposed:              True
exposed-modules:
    Language.C99.Simple Language.C99.Simple.AST
    Language.C99.Simple.Expr Language.C99.Simple.Translate
    Language.C99.Simple.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/language-c99-simple-0.2.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/language-c99-simple-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-c99-simple
hs-libraries:         HSlanguage-c99-simple-0.2.3-FO88MOT59BBAkxQlB4FWu0
depends:
    base-4.15.1.0 language-c99-0.2.0-9Bt25M1E0uV1rzIt32rIr9
    language-c99-util-0.2.0-G8ynpsGBaJV4EImmBrnmBl mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-language-c99-simple/html/language-c99-simple.haddock

haddock-html:         /usr/share/doc/haskell-language-c99-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c99-simple-0.3.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-c99-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 language-c99-simple
version:              0.3.0
visibility:           public
id:                   language-c99-simple-0.3.0-55WxmMMRTLqE9dZ3DDb4fL
key:                  language-c99-simple-0.3.0-55WxmMMRTLqE9dZ3DDb4fL
license:              MIT
maintainer:           Frank Dedden <dev@dedden.net>
author:               Frank Dedden
synopsis:             C-like AST to simplify writing C99 programs.
description:
    This package is a wrapper on top of '\''language-c99'\''. It provides a simpler
    interface more suited for writing C99 programs. It achieves this by
    implementing its own C-like AST, supporting the most used C features. In
    turn, this AST is translated into actual C99 one, showing that it is an
    actual subset.

category:             Language
abi:                  29f31f2590dea856e02ac2994461a380
exposed:              True
exposed-modules:
    Language.C99.Simple Language.C99.Simple.AST
    Language.C99.Simple.Expr Language.C99.Simple.Translate
    Language.C99.Simple.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/language-c99-simple-0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/language-c99-simple-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-c99-simple
hs-libraries:         HSlanguage-c99-simple-0.3.0-55WxmMMRTLqE9dZ3DDb4fL
depends:
    base-4.15.1.0 language-c99-0.2.0-9Bt25M1E0uV1rzIt32rIr9
    language-c99-util-0.2.0-G8ynpsGBaJV4EImmBrnmBl mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-language-c99-simple/html/language-c99-simple.haddock

haddock-html:         /usr/share/doc/haskell-language-c99-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
